@@ -1,6 +1,7 @@
 from stackifyapm.instrumentation.packages.base import AbstractInstrumentedModule
 from stackifyapm.traces import CaptureSpan
 from stackifyapm.utils import get_method_name
+from stackifyapm.utils.helper import is_async_span
 
 
 class PythonMemcachedInstrumentation(AbstractInstrumentedModule):
@@ -28,7 +29,7 @@ class PythonMemcachedInstrumentation(AbstractInstrumentedModule):
         "touch",
     ]
 
-    def get_instrument_list(self):
+    def get_instrument_list(self, config_file=None):
         method_list = [("memcache", "Client.{}".format(method)) for method in self.memcached_method_list]
         method_list += [("pymemcache.client.base", "Client.{}".format(method)) for method in self.memcached_method_list]
         return method_list
@@ -47,5 +48,5 @@ class PythonMemcachedInstrumentation(AbstractInstrumentedModule):
         if cache_name:
             extra_data['cache_key'] = cache_name
 
-        with CaptureSpan(name, "cache.memcached", extra_data):
+        with CaptureSpan(name, "cache.memcached", extra_data, is_async=is_async_span()):
             return wrapped(*args, **kwargs)
